@@ -127,7 +127,6 @@ class HttpClient(object):
         return response.text
 
     def _get(self, rest_command, parameters=None, headers=None):
-        print("sdfsdfdsffdsfds")
         return self._do_request('GET', rest_command, parameters,
                                 headers=headers)
 
@@ -356,7 +355,8 @@ class LoadMaster(HttpClient):
                 if vs['MasterVSID'] == this_vs_index:
                     subvs = VirtualService(self.access_info, vs['Index'])
                     subvs.populate_default_attributes(vs)
-                    subvs_api_entries = get_dict_entry_as_list("SubVS", data)
+                    #subvs_api_entries = get_dict_entry_as_list("SubVS", data)
+                    subvs_api_entries = service.get("SubVS", [])
                     for subvs_api in subvs_api_entries:
                         # add the "Rs" part of the subvs to the subvs instance
                         if subvs_api["VSIndex"] == subvs.index:
